<?php

namespace CRM\Controller;

use CRM\Traits\TResponse;
use CRM\Service\EvolucaoService;
use Zeedhi\Framework\DTO\Request;

class EvolucaoController
{
    protected $EvolucaoService;

    use TResponse;

    public function __construct(EvolucaoService $EvolucaoService)
    {
        $this->EvolucaoService = $EvolucaoService;
    }

    /**
     * Retrieves evolution tab data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getEvolutionTab(Request $request): array
    {
        try {
            $data = $this->EvolucaoService->getEvolutionTab($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    /**
     * Retrieves contact type data.
     *
     * @return array The response data.
     */
    public function getContactType(): array
    {
        try {
            $data = $this->EvolucaoService->getContactType();
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    /**
     * Retrieves evolution reason data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getEvolutionReason(Request $request): array
    {
        try {
            $data = $this->EvolucaoService->getEvolutionReason($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    public function getEvolutionReasonBasedOnOperator(Request $request): array
    {
        try {
            $data = $this->EvolucaoService->getEvolutionReasonBasedOnOperator($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    /**
     * Retrieves result data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getResult(Request $request): array
    {
        try {
            $data = $this->EvolucaoService->getResult($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    /**
     * Retrieves attachment data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function getAttachment(Request $request): array
    {
        try {
            $data = $this->EvolucaoService->getAttachment($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }

    /**
     * Retrieves attachment data.
     *
     * @param Request $request The HTTP request object.
     * @return array The response data.
     */
    public function saveNewEvolution(Request $request): array
    {
        try {
            $data = $this->EvolucaoService->saveNewEvolution($request->getParameters());
            $this->sendResponse($data, 200);
            return $data;
        } catch (\Exception $ex) {
            $this->sendResponse(['error' => $ex->getMessage(), 'code' => $ex->getCode()], 500);
            return [];
        }
    }
}
