<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class CrmCargoFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCrmCargo()
    {
        $sql = "SELECT * FROM CARGOINTERLOC ORDER BY CDCARGOINTERLOC ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertCrmCargo( $params )
    {
        $sql = "INSERT INTO CARGOINTERLOC
                       (CDCARGOINTERLOC,
                        NMCARGOINTERLOC,  
                        NRORG,
                        NRORGINCLUSAO,  
                        CDOPERINCLUSAO,
                        NRORGULTATU,  
                        CDOPERULTATU,    
                        IDATIVO,
                        DTINCLUSAO)        
                VALUES (:CDCARGOINTERLOC,
                        :NMCARGOINTERLOC,  
                        :NRORG,
                        :NRORGINCLUSAO,  
                        :CDOPERINCLUSAO,
                        :NRORGULTATU,  
                        :CDOPERULTATU,    
                        :IDATIVO, 
                        SYSDATE)";
        $this->connection->executeStatement($sql, $params);
       
    }


    public function editCrmCargo( $params )
    {
        
        $sql = "UPDATE CARGOINTERLOC
                SET 
                    NMCARGOINTERLOC            = :NMCARGOINTERLOC,
                    NRORG                      = :NRORG,
                    NRORGULTATU                = :NRORGULTATU,  
                    CDOPERULTATU               = :CDOPERULTATU,  
                    IDATIVO                    = :IDATIVO,
                    DTULTATU                   = SYSDATE
                WHERE CDCARGOINTERLOC              = :CDCARGOINTERLOC";
        $this->connection->executeStatement($sql, $params);

    }

    public function checkExistingCargo($params)
    {
        $sql = "SELECT
                    COUNT(*) AS VALIDA
                FROM
                    CARGOINTERLOC
                WHERE
                       UPPER (NMCARGOINTERLOC) = UPPER (:NMCARGOINTERLOC)
                    AND NRORG = :NRORG  AND CDCARGOINTERLOC <> :CDCARGOINTERLOC";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }

    public function deleteCrmCargo($params)
    {  
        $sql = "DELETE FROM CARGOINTERLOC
                WHERE CDCARGOINTERLOC   = :CDCARGOINTERLOC
                    AND NRORG               = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    

}