<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManagerInterface;
use CRM\Traits\TQuery;

class InterlocutorFactory
{
        use TQuery;

        protected $connection;

        protected $entityManager;

        public function __construct(EntityManagerInterface  $entityManager)
        {
                $this->connection = $entityManager->getConnection();
                $this->entityManager = $entityManager;
        }

        /**
         * Retrieves interlocutor data based on lead information.
         *
         * @param array $paramsQuery The query parameters.
         * @return array The interlocutor data.
         * @throws \Exception If an error occurs.
         */
        public function getInterlocutorBasedOnLead(array $paramsQuery): array
        {
                try {
                        $queryBuilder = $this->connection->createQueryBuilder();

                        $queryBuilder->select([
                                "INTERLOCUTOR.*",
                                "OPERADOR.CDOPERADOR",
                                "SETOR.NMSETOR",
                                "CARGO.NMCARGOINTERLOC",
                                "PAIS.NMPAIS",
                                "ESTADO.NMESTADO",
                                "MUNICIPIO.NMMUNICIPIO",
                                "BAIRRO.NMBAIRRO",
                                "PARCNEGOCIO.NMPRINCIPALPARC"
                        ])
                                ->from('CRM_INTERLOCUTOR', 'INTERLOCUTOR')
                                ->leftJoin('INTERLOCUTOR', 'CARGOINTERLOC', 'CARGO', 'INTERLOCUTOR.CDCARGOINTERLOC = CARGO.CDCARGOINTERLOC 
                        AND INTERLOCUTOR.NRORG = CARGO.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'SETOR', 'SETOR', 'INTERLOCUTOR.CDSETOR = SETOR.CDSETOR 
                        AND INTERLOCUTOR.NRORG = SETOR.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'PAIS', 'PAIS', 'INTERLOCUTOR.CDPAIS = PAIS.CDPAIS 
                        AND INTERLOCUTOR.NRORG = PAIS.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'ESTADO', 'ESTADO', 'INTERLOCUTOR.CDPAIS = ESTADO.CDPAIS
                        AND INTERLOCUTOR.SGESTADO = ESTADO.SGESTADO 
                        AND INTERLOCUTOR.NRORG = ESTADO.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'MUNICIPIO', 'MUNICIPIO', 'INTERLOCUTOR.CDPAIS = MUNICIPIO.CDPAIS
                        AND INTERLOCUTOR.SGESTADO = MUNICIPIO.SGESTADO 
                        AND INTERLOCUTOR.CDMUNICIPIO = MUNICIPIO.CDMUNICIPIO 
                        AND INTERLOCUTOR.NRORG = MUNICIPIO.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'BAIRRO', 'BAIRRO', 'INTERLOCUTOR.CDPAIS = BAIRRO.CDPAIS 
                        AND INTERLOCUTOR.SGESTADO = BAIRRO.SGESTADO 
                        AND INTERLOCUTOR.CDMUNICIPIO = BAIRRO.CDMUNICIPIO 
                        AND INTERLOCUTOR.CDBAIRRO = BAIRRO.CDBAIRRO 
                        AND INTERLOCUTOR.NRORG = BAIRRO.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'OPERADOR', 'OPERADOR', 'INTERLOCUTOR.NRPARCNEGOCIO = OPERADOR.NRPARCNEGOCIO
                        AND INTERLOCUTOR.NRORG = OPERADOR.NRORG')
                                ->leftJoin('INTERLOCUTOR', 'PARCNEGOCIO', 'PARCNEGOCIO', 'INTERLOCUTOR.NRPARCNEGOCIO = PARCNEGOCIO.NRPARCNEGOCIO 
                        AND INTERLOCUTOR.NRORG = PARCNEGOCIO.NRORG')
                                ->where('INTERLOCUTOR.NRORG = :NRORG')
                                ->andWhere('INTERLOCUTOR.IDATIVO = :IDATIVO')
                                ->andWhere('INTERLOCUTOR.NRPARCNEGOCIO = :NRPARCNEGOCIO');

                        $queryBuilder->setParameters($paramsQuery);
                        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
                } catch (\Exception $e) {
                        throw $e;
                }
        }

        /**
         * Retrieves sectors from the database based on provided parameters.
         *
         * @param array $paramsQuery The parameters for the query.
         * @return array The retrieved sectors.
         * @throws \Exception If an error occurs during the database operation.
         */
        public function getSector(array $paramsQuery): array
        {
                $queryBuilder = $this->connection->createQueryBuilder();

                try {
                        $queryBuilder
                                ->select(["SETOR.*"])
                                ->from('SETOR', 'SETOR')
                                ->where(
                                        $queryBuilder->expr()->and(
                                                $queryBuilder->expr()->eq('SETOR.NRORG', ':NRORG'),
                                                $queryBuilder->expr()->eq('SETOR.IDATIVO', ':IDATIVO'),
                                                $queryBuilder->expr()->notLike('SETOR.NMSETOR', ':prefix1'),
                                                $queryBuilder->expr()->notLike('SETOR.NMSETOR', ':prefix2')
                                        )
                                );

                        $queryBuilder->setParameters($paramsQuery);
                        $queryBuilder->setParameter('prefix1', 'INAT%');
                        $queryBuilder->setParameter('prefix2', 'INATIVO%');

                        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
                } catch (\Exception $e) {
                        // Optionally handle or log the exception here
                        throw $e;
                }
        }

        public function getPosition(array $paramsQuery): array
        {
                $queryBuilder = $this->connection->createQueryBuilder();

                try {
                        $queryBuilder
                                ->select(["CARGOINTERLOC.*"])
                                ->from('CARGOINTERLOC', 'CARGOINTERLOC')
                                ->where(
                                        $queryBuilder->expr()->and(
                                                $queryBuilder->expr()->eq('CARGOINTERLOC.NRORG', ':NRORG'),
                                                $queryBuilder->expr()->eq('CARGOINTERLOC.IDATIVO', ':IDATIVO')
                                        )
                                );

                        $queryBuilder->setParameters($paramsQuery);
                        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $queryBuilder->getSQL(), $queryBuilder->getParameters());
                } catch (\Exception $e) {
                        // Optionally handle or log the exception here
                        throw $e;
                }
        }
}
