<?php

namespace CRM\Service;

use CRM\Factory\LeadFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;
use CRM\Util\Utilities;

class LeadService
{
    protected $newCode;
    protected $connection;
    protected $LeadFactory;
    protected $Environment;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, LeadFactory $LeadFactory)
    {
        $this->LeadFactory                        = $LeadFactory;
        $this->Environment                        = $Environment;
        $this->newCode                            = $newCode;
        $this->connection                         = $entityManager->getConnection();
    }

    private function returnInscriptionType($inscription)
    {

        switch ($inscription) {

            case 'J':
                $inscription = 'CNPJ';
                break;
            case 'F':
                $inscription = 'CPF';
                break;
            case 'I':
                $inscription = 'LIVRE';
                break;
            case 'O':
                $inscription = 'CODIGO';
                break;
            default:
                $inscription = 'LIVRE';
                break;
        }
        return $inscription;
    }

    private function normalizeIDTPIJURCAN($idtPijurcan): ?string
    {
        // Se for CNPJ, substitua por 'J'; se for CPF, substitua por 'F'
        if ($idtPijurcan === 'CNPJ') {
            return 'J';
        } elseif ($idtPijurcan === 'CPF') {
            return 'F';
        }

        return null; // Se não for nem CNPJ nem CPF, retorna null ou faça outra ação de validação se necessário
    }


    private function getOperatorInformation($nrorg, $nrparceiro): array
    {
        try {
            $params = array(
                "NRORG" => $nrorg,
                "NRPARCNEGOCIO" => $nrparceiro
            );
            return $this->LeadFactory->getOperatorInformation($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function leadValidate($row)
    {
        try {
            $leads = array();

            $nrorg = $this->Environment->getNrorg();
            $crm_nrorgtrab = $this->Environment->getNrorg();
            $row['PKVALUE'] = isset($row['NRPARCNEGOCIO']) ? $row['NRPARCNEGOCIO'] : null;

            if (!empty($row['NRINSJURCAN'])) {
                $leads = $this->verifyLeadByInsJurcan($row, $nrorg, $crm_nrorgtrab);
            } elseif (!empty($row['NMCANDIDATO'])) {
                $leads = $this->verifyLeadByName($row, $nrorg, $crm_nrorgtrab);
            }

            return $leads;
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function verifyLeadByInsJurcan($row, $nrorg, $crm_nrorgtrab)
    {
        $params = array(
            "NRORG"         => $nrorg,
            "CRM_NRORGTRAB" => $crm_nrorgtrab,
            "PKVALUE"       => $row["PKVALUE"],
            "INSCRICAO"     => $row["NRINSJURCAN"],
        );

        if ($row['IDTPIJURCAN'] === 'J') {
            $leads = $this->LeadFactory->verifyLeadCNPJ($params);
            if (!empty($leads) && isset($row['IDVALIDACNPJ']) && $row['IDVALIDACNPJ'] == 'N') {
                $leads = $this->LeadFactory->verifyLeadExactCNPJ($params);
            }
        } else {
            $leads = $this->LeadFactory->verifyLeadInsc($params);
        }

        return $leads;
    }

    private function verifyLeadByName($row, $nrorg, $crm_nrorgtrab)
    {
        $params = array(
            "NRORG"         => $nrorg,
            "CRM_NRORGTRAB" => $crm_nrorgtrab,
            "PKVALUE"       => $row["PKVALUE"],
            "NMCANDIDATO"   => $row["NMCANDIDATO"],
        );

        $leads = $this->LeadFactory->verifyLeadName($params);
        if (empty($leads['data'])) {
            // $similarLeads = $this->LeadFactory->findSimilarLeads($params);
            if (!empty($similarLeads)) {
                // Realizar alguma ação, como notificar o operador
                echo "Atenção: Possíveis correspondências encontradas!";
            }
        }

        return $leads;
    }

    private function verifyExistenceLead($lead, $exlusiveParc, $nrorg)
    {
        try {
            $lead['data'][0]['EXCLUSIVEPARC'] = $exlusiveParc;
            $enderecoParc = $this->LeadFactory->returnParcAddress($lead['data'][0]['NRPARCNEGOCIO'], $lead['data'][0]['NRORG']);

            if (!empty($enderecoParc)) {
                $enderecoParc = $enderecoParc;
                $lead['data'][0]['CDPAIS'] = $enderecoParc['data'][0]['CDPAIS'];
                $lead['data'][0]['NMPAIS'] = $enderecoParc['data'][0]['NMPAIS'];
                $lead['data'][0]['SGESTADO'] = $enderecoParc['data'][0]['SGESTADO'];
                $lead['data'][0]['NMESTADO'] = $enderecoParc['data'][0]['NMESTADO'];
                $lead['data'][0]['CDMUNICIPIO'] = $enderecoParc['data'][0]['CDMUNICIPIO'];
                $lead['data'][0]['NMMUNICIPIO'] = $enderecoParc['data'][0]['NMMUNICIPIO'];
                $lead['data'][0]['CDBAIRRO'] = $enderecoParc['data'][0]['CDBAIRRO'];
                $lead['data'][0]['NMBAIRRO'] = $enderecoParc['data'][0]['NMBAIRRO'];
                $lead['data'][0]['NRIMOVELENDERECO'] = $enderecoParc['data'][0]['NRIMOVELENDERECO'];
                $lead['data'][0]['CDBAIRRO'] = $enderecoParc['data'][0]['CDBAIRRO'];
                $lead['data'][0]['NRCEPENDERECO'] = $enderecoParc['data'][0]['NRCEPENDERECO'];
                $lead['data'][0]['DSCOMPLEENDERECO'] = $enderecoParc['data'][0]['DSCOMPLEENDERECO'];
                $lead['data'][0]['DSENDERECO'] = $enderecoParc['data'][0]['DSENDERECO'];
            }
            $comunicaParc = $this->LeadFactory->findEmailAndTel($lead['data'][0]['NRPARCNEGOCIO'], $nrorg);
            $lead['data'][0]['DSEMAILCAN'] = !empty($comunicaParc['EMAIL']) ? $comunicaParc['EMAIL']['CDCOMUNICAPARC'] : "";
            $lead['data'][0]['DSTELEFONECAN'] = !empty($comunicaParc['TELEFONE']) ? $comunicaParc['TELEFONE']['CDCOMUNICAPARC'] : "";
            return $lead['data'][0];
        } catch (\Exception $e) {
            throw $e;
        };
    }

    private function verifyExistenceProspect($prospect, $nrparcnegocio, $exlusiveParc, $nrorg)
    {
        try {
            if (!empty($lead)) {
                $prospect['data'][0]['NRCANDIDATO'] = $lead['data'][0]['NRCANDIDATO'];
                $prospect['data'][0]['DESCTITULOCAN'] = $lead['data'][0]['DESCTITULOCAN'];
                $prospect['data'][0]['LEADEXISTS'] = true;
                $prospect['data'][0]['NRCONTATO'] = $lead['data'][0]['NRCONTATO'];
                $prospect['data'][0]['NRSEQCONTATO'] = $lead['data'][0]['NRSEQCONTATO'];
            } else {
                $prospect['data'][0]['IDSTATUSCAN'] = 3;
                if (empty($prospect['data'][0]['IDPARCFUNDIDO'])) {
                    $prospect['data'][0]['IDPARCFUNDIDO'] = 'N';
                }
                $prospect['data'][0]['LEADEXISTS'] = false;
            }
            $prospect['data'][0]['NRINSJURCAN'] = $prospect['data'][0]['NRINSJURPROS'];
            $prospect['data'][0]['EXCLUSIVEPARC'] = $exlusiveParc;

            $comunicaParc = $this->LeadFactory->findEmailAndTel($nrparcnegocio, $nrorg);
            $prospect['data'][0]['DSEMAILCAN'] = !empty($comunicaParc['EMAIL']) ? $comunicaParc['EMAIL']['CDCOMUNICAPARC'] : "";
            $prospect['data'][0]['DSTELEFONECAN'] = !empty($comunicaParc['TELEFONE']) ? $comunicaParc['TELEFONE']['CDCOMUNICAPARC'] : "";

            $enderecoParc = $this->LeadFactory->returnParcAddress($prospect['data'][0]['NRPARCNEGOCIO'], $prospect['data'][0]['NRORG']);
            if (!empty($enderecoParc)) {
                $enderecoParc = $enderecoParc;
                $prospect['data'][0]['CDPAIS'] = $enderecoParc['data'][0]['CDPAIS'];
                $prospect['data'][0]['NMPAIS'] = $enderecoParc['data'][0]['NMPAIS'];
                $prospect['data'][0]['SGESTADO'] = $enderecoParc['data'][0]['SGESTADO'];
                $prospect['data'][0]['NMESTADO'] = $enderecoParc['data'][0]['NMESTADO'];
                $prospect['data'][0]['CDMUNICIPIO'] = $enderecoParc['data'][0]['CDMUNICIPIO'];
                $prospect['data'][0]['NMMUNICIPIO'] = $enderecoParc['data'][0]['NMMUNICIPIO'];
                $prospect['data'][0]['CDBAIRRO'] = $enderecoParc['data'][0]['CDBAIRRO'];
                $prospect['data'][0]['NMBAIRRO'] = $enderecoParc['data'][0]['NMBAIRRO'];
                $prospect['data'][0]['NRIMOVELENDERECO'] = $enderecoParc['data'][0]['NRIMOVELENDERECO'];
                $prospect['data'][0]['CDBAIRRO'] = $enderecoParc['data'][0]['CDBAIRRO'];
                $prospect['data'][0]['NRCEPENDERECO'] = $enderecoParc['data'][0]['NRCEPENDERECO'];
                $prospect['data'][0]['DSCOMPLEENDERECO'] = $enderecoParc['data'][0]['DSCOMPLEENDERECO'];
                $prospect['data'][0]['DSENDERECO'] = $enderecoParc['data'][0]['DSENDERECO'];
            }
            if (!empty($prospect['data'][0]['CDSEGMER'])) {
                $segmer = $this->LeadFactory->searchSegMerc($prospect['data'][0]['CDSEGMER'], $prospect['data'][0]['NRORG']);
                if ($segmer) {
                    $prospect['data'][0]['DSSEGMER'] = $segmer['DSSEGMER'];
                }
            }
            return $prospect['data'][0];
        } catch (\Exception $e) {
            throw $e;
        };
    }

    private function verifyExistenceClient($client, $nrparcnegocio, $exlusiveParc, $nrorg)
    {
        try {
            if (!empty($lead)) {
                $client['data'][0]['NRCANDIDATO'] = $lead['data'][0]['NRCANDIDATO'];
                $client['data'][0]['DESCTITULOCAN'] = $lead['data'][0]['DESCTITULOCAN'];
                $client['data'][0]['NRCONTATO'] = $lead['data'][0]['NRCONTATO'];
                $client['data'][0]['NRSEQCONTATO'] = $lead['data'][0]['NRSEQCONTATO'];
                $client['data'][0]['LEADEXISTS'] = true;
            } else {
                $client['data'][0]['IDPARCFUNDIDO'] = 'N';
                $client['data'][0]['IDSTATUSCAN'] = 3;
                $client['data'][0]['LEADEXISTS'] = false;
            }
            if (!empty($prospect)) {
                $client['data'][0]['PROSPEXISTS'] = true;
            } else {
                $client['data'][0]['PROSPEXISTS'] = false;
            }

            $client['data'][0]['NRINSJURCAN'] = $client['data'][0]['NRINSJURCLIE'];
            $client['data'][0]['NRINSJURPROS'] = $client['data'][0]['NRINSJURCLIE'];
            $client['data'][0]['EXCLUSIVEPARC'] = $exlusiveParc;

            $comunicaParc = $this->LeadFactory->findEmailAndTel($nrparcnegocio, $nrorg);
            $client['data'][0]['DSEMAILCAN'] = !empty($comunicaParc['EMAIL']) ? $comunicaParc['EMAIL']['CDCOMUNICAPARC'] : "";
            $client['data'][0]['DSTELEFONECAN'] = !empty($comunicaParc['TELEFONE']) ? $comunicaParc['TELEFONE']['CDCOMUNICAPARC'] : "";

            $enderecoParc = $this->LeadFactory->returnParcAddress($client['data'][0]['NRPARCNEGOCIO'], $client['data'][0]['NRORG']);
            if (!empty($enderecoParc)) {
                $enderecoParc = $enderecoParc;
                $client['data'][0]['CDPAIS'] = $enderecoParc['data'][0]['CDPAIS'];
                $client['data'][0]['NMPAIS'] = $enderecoParc['data'][0]['NMPAIS'];
                $client['data'][0]['SGESTADO'] = $enderecoParc['data'][0]['SGESTADO'];
                $client['data'][0]['NMESTADO'] = $enderecoParc['data'][0]['NMESTADO'];
                $client['data'][0]['CDMUNICIPIO'] = $enderecoParc['data'][0]['CDMUNICIPIO'];
                $client['data'][0]['NMMUNICIPIO'] = $enderecoParc['data'][0]['NMMUNICIPIO'];
                $client['data'][0]['CDBAIRRO'] = $enderecoParc['data'][0]['CDBAIRRO'];
                $client['data'][0]['NMBAIRRO'] = $enderecoParc['data'][0]['NMBAIRRO'];
                $client['data'][0]['NRIMOVELENDERECO'] = $enderecoParc['data'][0]['NRIMOVELENDERECO'];
                $client['data'][0]['NRCEPENDERECO'] = $enderecoParc['data'][0]['NRCEPENDERECO'];
                $client['data'][0]['DSCOMPLEENDERECO'] = $enderecoParc['data'][0]['DSCOMPLEENDERECO'];
                $client['data'][0]['DSENDERECO'] = $enderecoParc['data'][0]['DSENDERECO'];
            }
            if (!empty($client['data'][0]['CDSEGMER'])) {
                $segmer = $this->LeadFactory->searchSegMerc($client['data'][0]['CDSEGMER'], $client['data'][0]['NRORG']);
                if ($segmer) {
                    $client['data'][0]['DSSEGMER'] = $segmer['DSSEGMER'];
                }
            }
            return $client['data'][0];
        } catch (\Exception $e) {
            throw $e;
        };
    }

    public function verifyExistencePartner($row)
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $crm_nrorgtrab = $this->Environment->getNrorg();
            $razSoc = null;
            $nomFant = null;

            if (isset($row['NMCANDIDATO'])) {
                $razSoc = $row['NMCANDIDATO'];
                $nomFant = $row['NMFANTCAN'];
            } elseif (isset($row['NMRAZSOCPROS'])) {
                $razSoc = $row['NMRAZSOCPROS'];
                $nomFant = $row['NMFANTPROS'];
            } elseif (isset($row['NMRAZSOCCLIE'])) {
                $razSoc = $row['NMRAZSOCCLIE'];
                $nomFant = $row['NMFANTCLIE'];
            }

            $return = false;

            if (empty($row['INSCRICAO'])) {
                if ($razSoc !== null) {
                    $return = $this->LeadFactory->findSimilarName($razSoc, $nomFant, $nrorg);
                }
            } else {
                if (isset($row['INSCRICAO'])) {
                    $return = $this->LeadFactory->findParcByRegistration($nrorg, $row['INSCRICAO'], $row['IDTPIJURCAN']);
                }
            }

            if (isset($return) && !empty($return['data'])) {
                return $this->getPartnerData($return['data'][0]['NRPARCNEGOCIO'], $nrorg, $crm_nrorgtrab);
            } else {
                return false;
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function getPartnerData($nrparcnegocio, $nrorg, $crm_nrorgtrab)
    {
        try {
            $client = $this->LeadFactory->findClient($nrparcnegocio, $nrorg, $crm_nrorgtrab);
            $prospect = $this->LeadFactory->findProspect($nrparcnegocio, $nrorg, $crm_nrorgtrab);
            $lead = $this->LeadFactory->findCandidate($nrparcnegocio, $nrorg, $crm_nrorgtrab);
            $exlusiveParc = empty($this->LeadFactory->findExclusiveParc($nrparcnegocio, $nrorg, $crm_nrorgtrab)) ? true : false;

            if (!empty($client['data'])) {
                return $this->verifyExistenceClient($client, $nrparcnegocio, $exlusiveParc, $nrorg);
            } else if (!empty($prospect['data'])) {
                return $this->verifyExistenceProspect($prospect, $nrparcnegocio, $exlusiveParc, $nrorg);
            } else if (!empty($lead['data'])) {
                return $this->verifyExistenceLead($lead, $exlusiveParc, $nrorg);
            } else {
                return false;
            }
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getCdOperador()
    {
        try {
            return array(
                "NRPARCPROPRI" => $this->Environment->getCdOperador(),
            );
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getResponsibleOperator($rows)
    {
        $nrorg = $this->Environment->getNrorg();
        try {
            $params = array(
                "NRORG" => $nrorg,
                "IDOPERATIVO" => $rows['IDOPERATIVO'] ?? 'A',
            );
            return $this->LeadFactory->getResponsibleOperator($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getMarketSegment()
    {
        $nrorg = $this->Environment->getNrorg();
        try {
            $params = array(
                "NRORG" => $nrorg,
            );
            return $this->LeadFactory->getMarketSegment($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function getLeads($params)
    {
        try {
            $nrorg = $this->Environment->getNrorg();
            $params = array(
                "NRORG" => $nrorg,
                "CRM_NRORGTRAB" => $nrorg,
                "NMCANDIDATO" => $params["NMCANDIDATO"] ?? null,
                "NMFANTCAN" => $params["NMFANTCAN"] ?? null,
                "NRINSJURCAN" => $params["NRINSJURCAN"] ?? null,
                "INCLUSAO" => $params["INCLUSAO"] ?? null,
                "IDSTATUSCAN" => $params["IDSTATUSCAN"] ?? null,
                "IDATIVO" => $params["IDATIVO"] ?? null,
                "IDOPERATIVO" => $params["IDOPERATIVO"] ?? null,
                "NRPARCPROPRI" => $params["NRPARCPROPRI"] ?? null,
                "PERFATUSEGMER" => $params["PERFATUSEGMER"] ?? null,
                "DSSEGMER" => $params["DSSEGMER"] ?? null,
                "CDPAIS" => $params["CDPAIS"] ?? null,
                "SGESTADO" => $params["SGESTADO"] ?? null,
                "CDMUNICIPIO" => $params["CDMUNICIPIO"] ?? null,
                "CDBAIRRO" => $params["CDBAIRRO"] ?? null,
                "STATUSPARC" => $params["STATUSPARC"] ?? 'CANDIDATO',
            );
            
            return $this->LeadFactory->getLeads($params);
        } catch (\Error $e) {
            throw $e;
        }
    }

    public function saveNewLeads($row)
    {
        try {
            $this->connection->beginTransaction();

            $criaNovoContato = false;
            $fundeParc = false;
            $row["NRORG"] = $this->Environment->getNrorg();

            $row['IDTPIJURCAN'] = !empty($row['IDTPIJURCAN']) ? $this->returnInscriptionType($row['IDTPIJURCAN']) : 'I';
            $row['CDOPERRESPONSAVEL'] = $row['CDOPERADOR'];
            $row['NRPARCRESP'] = $row['NRPARCPROPRI'];
            $row['CDPAIS'] = empty($row['CDPAIS']) ? '' : $row['CDPAIS'];
            $row['SGESTADO'] = empty($row['SGESTADO']) ? '' : $row['SGESTADO'];
            $row['CDMUNICIPIO'] = empty($row['CDMUNICIPIO']) ? '' : $row['CDMUNICIPIO'];
            $row['CDBAIRRO'] = empty($row['CDBAIRRO']) ? '' : $row['CDBAIRRO'];
            if (empty($row["NRCANDIDATO"])) {
                $row["CDFILIAL"] = $this->Environment->getCdFilial();
                $row["CDTIPOPARCEIRO"] = "CANDIDATO";

                $parcCriado = $this->verifyExistencePartner($row);
                if (empty($parcCriado)) {
                    $row['NRCANDIDATO'] = $this->newCode->getCodeByTableName("CANDIDATO9999", $row["NRORG"]);
                    $row['NRPARCNEGOCIO'] = $this->newCode->getCodeByTableName("PARCNEGOCIO", $row["NRORG"]);
                    $row['NRSEQCONTATO'] = $this->newCode->getCodeByTableName("NRSEQCONTATO", $row["NRORG"]);
                    $row['IDPARCFUNDIDO'] = 'N';
                    $row['NRCONTATO'] = $row['NRSEQCONTATO'];
                    $row['__is_new'] = true;
                    $criaNovoContato = true;
                    if (empty($row['NRPARCNEGOCIO'])) {
                        $row['NRPARCNEGOCIO'] = $parcCriado['NRPARCNEGOCIO'];
                    }
                } else {
                    if (empty($row['NRCANDIDATO'])) {
                        $row['NRCANDIDATO'] = $this->newCode->getCodeByTableName("CANDIDATO9999", $row["NRORG"]);
                        $row['__is_new'] = true;
                    } else {
                        $row['__is_new'] = false;
                    }
                    if (empty($row['NRSEQCONTATO'])) {
                        $row['NRSEQCONTATO'] = $this->newCode->getCodeByTableName("NRSEQCONTATO", $row["NRORG"]);
                        $row['NRCONTATO'] = $row['NRSEQCONTATO'];
                        $criaNovoContato = true;
                    }
                }
                /**
                 * Checks if $parcCriado is not empty and if $parcCriado['NRPARCNEGOCIO'] is not empty.
                 * If $row['NRPARCNEGOCIO'] is empty, assigns the value of $parcCriado['NRPARCNEGOCIO'] to $row['NRPARCNEGOCIO'].
                 *
                 * @param array $parcCriado The array containing the created parcel information.
                 * @param array $row The array containing the row information.
                 * @return void
                 */
                if (!empty($parcCriado) && !empty($parcCriado['NRPARCNEGOCIO']) && empty($row['NRPARCNEGOCIO'])) {
                    $row['NRPARCNEGOCIO'] = $parcCriado['NRPARCNEGOCIO'];
                }
                /**
                 * Inserts the Parcnegocio and optionally creates a new Contato.
                 *
                 * @param array $row The data row to be processed.
                 * @param bool $parcCriado Indicates if the Parcnegocio was already created.
                 * @param bool $criaNovoContato Indicates if a new Contato should be created.
                 * @return void
                 */
                $this->insertParcnegocio($row, !empty($parcCriado));
                // Optionally creates a new Contato
                if ($criaNovoContato) {
                    $this->newContato($row);
                }
                // Creates a partnership or handles the case where it exists but is not associated with any lead
                if (empty($parcCriado)) {
                    $this->createPartnership($row);
                } else if (isset($parcCriado['LEADEXISTS']) && !$parcCriado['LEADEXISTS']) {
                    $this->createPartnershipNotExistent($row, 'CANDIDATO');
                }
                if ($row['NRMODORECEBINFO']) {
                    $this->setModoRecebInfo($row);
                }
                if (!empty($row["NMINTERLOCUTOR"])) {
                    $this->newInterlocutor($row);
                }
            } else {
                $parcCriado = $this->verifyExistencePartner($row);
                if (!empty($parcCriado) && !empty($row['PARCORIGINAL'] && $row['PARCORIGINAL'] !== $row['NRPARCNEGOCIO'])) {
                    $row["CDTIPOPARCEIRO"] = "CANDIDATO";
                    $this->mergePartner($row);
                    $this->deactivateParcStatus($row);
                    $this->insertStatusParc($row);
                }
                if ($this->checkReceiveModeInfo($row)) {
                    $this->updateModoRecebInfo($row);
                } else if ($row['NRMODORECEBINFO']) {
                    $this->setModoRecebInfo($row);
                }
            }

            $this->saveComunicaparc($row);
            $this->saveDtnascifundparc($row);
            $this->saveAddressParc($row);
            $this->saveLead($row);
            $this->updateResponsavel($row);
            // $this->leadService->alteraAtivoStatusParc($row);

            $this->connection->commit();
            // return $this->LeadFactory->saveNewLeads($params);
        } catch (\Error $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    public function insertParcnegocio($row, $parcCriado)
    {
        try {
            $this->connection->beginTransaction();

            $params = array(
                "CDTIPOPARCPRINCIPAL"   => "CANDIDATO",
                "IDPESSOAFISICA"        => isset($row["ISCPF"]) ? $row["ISCPF"] : 'N',
                "NRORG"                 => $row["NRORG"],
                "NRORGINCLUSAO"         => $row["NRORG"],
                "IDATIVO"               => $row["IDATIVO"],
                "NMSECUNDARIPARC"       => $row["NMFANTCAN"],
                "CDOPERRESP"            => $row["CDOPERADOR"],
                "CDOPERULTATU"          => $row["CDOPERADOR"],
                "CDOPERINCLUSAO"        => $row["CDOPERADOR"],
                "STATUSPARC"            => $row["CDTIPOPARCEIRO"],
                "CRM_NRORGTRAB"         => $row["NRORG"],
                "NRORGULTATU"           => $row["NRORG"],
                "NMPRINCIPALPARC"       => $row["NMCANDIDATO"],
                "NRINSCRICAOPARC"       => $row["NRINSJURCAN"],
                "CDTIPOINSCRICAO"       => $row["IDTPIJURCAN"],
                "NRPARCRESP"            => $row["NRPARCPROPRI"],
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "IDSTATUS"              => isset($row["IDSTATUS"]) ? $row["IDSTATUS"] : '',
            );

            if (!$parcCriado) {
                $this->LeadFactory->insertParcnegocio($params);
            }
            $retorno = $this->LeadFactory->insertStatusParc($params);
            $this->connection->commit();

            return $retorno;
        } catch (\Error $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    public function newContato($row)
    {
        try {
            $this->connection->beginTransaction();

            // Verificar e Atribuir a Filial do Operador
            $filiOper = $this->verificaFilialOper($row["CDOPERADOR"], $row["NRORG"]);
            if (is_array($filiOper)) {
                if (\Zeedhi\Framework\Util\Functions::arrayKeyExists("CDFILIAL", $filiOper)) {
                    $row['CDFILIAL'] = $filiOper["CDFILIAL"];
                } else {
                    $row['CDFILIAL'] = null;
                }
            } else {
                $row['CDFILIAL'] = null;
            }

            // Preparar Parâmetros para Inserção
            $params = array(
                "DSREFECONT"    => substr('Referente ao Lead ' . $row['NMCANDIDATO'], 0, 59),
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "NRSEQCONTATO"  => $row['NRSEQCONTATO'],
                "CDOPERCONT"    => $row['CDOPERADOR'],
                "NRCONTATO"     => $row['NRCONTATO'],
                "CDFILIAL"      => $row['CDFILIAL'],
                "NRORG"         => $row['NRORG'],
                "IDSTATUSCONT"  => 'A',
                "IDTPCONTATO"   => 'P',
                "IDATIVO"       => $row['IDATIVO'],
            );

            // Adicionar Informações Adicionais
            $additionalInformation = $this->getInfoForInsertContato($params);
            $params["CDCLIENTE"] = $additionalInformation[0]["CDCLIENTE"];
            $params["CDPROSPECT"] = $additionalInformation[0]["CDPROSPECT"];
            $params["CDFORNECED"] = $additionalInformation[0]["CDFORNECED"];

            // Inserir o Contato
            $this->LeadFactory->insertnewContato($params);

            // Confirmar Transação
            $this->connection->commit();
        } catch (\Throwable $th) {
            // Tratamento de Exceção
            $this->connection->rollBack(); // Em caso de exceção, fazemos o rollback da transação
            throw $th;
        }
    }

    public function getInfoForInsertContato($params)
    {
        try {

            $params = array(
                "NRORG"         => $params['NRORG'],
                "IDATIVO"       => $params['IDATIVO'],
                "CDFILIAL"      => $params['CDFILIAL'],
                "NRCONTATO"     => $params['NRCONTATO'],
                "DSREFECONT"    => $params['DSREFECONT'],
                "CDOPERCONT"    => $params['CDOPERCONT'],
                "IDTPCONTATO"   => $params['IDTPCONTATO'],
                "IDSTATUSCONT"  => $params['IDSTATUSCONT'],
                "NRSEQCONTATO"  => $params['NRSEQCONTATO'],
                "NRPARCNEGOCIO" => $params['NRPARCNEGOCIO'],
            );

            return $this->LeadFactory->getInfoContato($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function verificaFilialOper($cdoper, $nrorg)
    {
        try {

            $paramsVerifyFilial = array(
                "CDOPERADOR" => $cdoper,
                "NRORG" => $nrorg
            );

            $filialOper = $this->LeadFactory->verifyFilialOper($paramsVerifyFilial);
            $retorno = isset($filialOper['data'][0]) ? $filialOper['data'][0] : null;
            return $retorno;
        } catch (\Exception $retorno) {
            return $retorno->getMessage();
        }
        return $retorno;
    }

    public function createPartnership($row)
    {
        try {
            $this->connection->beginTransaction();
            $nrparceiro = $this->newCode->getCodeByTableName("PARCERIA", $row["NRORG"], 1, 10, false, true);
            $cdoperinclusao = isset($row['CDOPERADOR']) ? $row['CDOPERADOR'] : $this->Environment->getCdOperador();

            $params = array(
                "NRPARCERIA"     => $nrparceiro,
                "CDOPERINCLUSAO" => $cdoperinclusao,
                "NRORG"          => $row["NRORG"],
                "NRORGINCLUSAO"  => $row["NRORG"],
                "IDATIVO"        => $row["IDATIVO"],
                "NRPARCNEGOCIO"  => $row['NRPARCNEGOCIO'],
                "CDTIPOPARCEIRO" => $row["CDTIPOPARCEIRO"],
            );

            $this->LeadFactory->createPartnership($params);

            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    public function createPartnershipNotExistent($row, $tipo = 'PROSPECT')
    {
        try {
            $this->connection->beginTransaction();
            // verifica se não foi adicionado uma parceria para o tipo do parceiro no meio tempo de execução da rotina
            $existente = $this->verifyExistentPartnership($row);

            if ($existente) {
                $nrparceiro = $this->newCode->getCodeByTableName("PARCERIA", $row["NRORG"], 1, 10, false, true);
                $cdoperinclusao = isset($row['CDOPERADOR']) ? $row['CDOPERADOR'] : $this->Environment->getCdOperador();

                $params = array(
                    "NRPARCERIA"     => $nrparceiro,
                    "NRORG"          => $row['NRORG'],
                    "NRPARCNEGOCIO"  => $row['NRPARCNEGOCIO'],
                    "CDTIPOPARCEIRO" => $tipo,
                    "IDATIVO"        => $row["IDATIVO"],
                    "CDOPERINCLUSAO" => $cdoperinclusao,
                    "NRORGINCLUSAO"  => $row["NRORG"],
                );
                $this->LeadFactory->queryInsertParceria($params);
            }

            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    private function verifyExistentPartnership($row)
    {
        try {
            $this->connection->beginTransaction();

            $params = array(
                "NRORG"         => $row['NRORG'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "CDTIPOPARCEIRO" => $row['CDTIPOPARCEIRO']
            );
            $this->LeadFactory->verifyExistentPartnership($params);

            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    public function setModoRecebInfo($row)
    {
        try {
            $this->connection->beginTransaction();

            $params = array(
                "NRORG" => $row['NRORG'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "NRMODORECEBINFO" => $row['NRMODORECEBINFO'],
            );
            $this->LeadFactory->setModoRecebInfo($params);

            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    public function newInterlocutor($row)
    {
        try {
            $this->connection->beginTransaction();
            $row['NRSEQINTERLOCUTOR'] = $this->newCode->getCodeByTableName("CRM_INTERLOCUTOR", $row['NRORG'], 1, 10, false, true);

            $params = array(
                "NRORG" => $row['NRORG'],
                "IDATIVO" => $row['IDATIVO'],
                "CDOPERINCLUSAO" => $row['CDOPERADOR'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "NMINTERLOCUTOR" => $row['NMINTERLOCUTOR'],
                "NRSEQINTERLOCUTOR" => $row['NRSEQINTERLOCUTOR'],
                "EMAILINTERLOC"     => $row["EMAILINTERLOC"],
                "NRTELEFONE1"       => $row["NRTELEFONE1"],
            );

            $this->LeadFactory->insertNewInterlocutor($params);

            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    public function mergePartner($row)
    {
        try {
            $this->connection->beginTransaction();

            $params = array(
                "NRORG" => $row['NRORG'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "PARCORIGINAL" => $row['PARCORIGINAL'],
                "CDOPERDESFUSAO" => $row['CDOPERADOR'],
                "CDOPERADOR" => $row['CDOPERADOR'],
            );

            $seq = $this->LeadFactory->getNrMaxMergeSeq($params['NRORG']);
            $params['NRSEQFUSAO'] = $seq[0]['NRSEQFUSAO'];

            $this->LeadFactory->mergePartner($params);
            $this->LeadFactory->updateParcNegocio($params);
            $this->LeadFactory->updateContato($row);
            $this->LeadFactory->updateOpportunity($row);
            $this->LeadFactory->updateFilaContato($row);
            $this->LeadFactory->updatePlanoOcupacao($row);

            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    public function deactivateParcStatus($row)
    {
        try {
            $this->connection->beginTransaction();
            $params = array(
                "NRORG" => $row['NRORG'],
                "CRM_NRORGTRAB" => $row['NRORG'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
            );

            $this->LeadFactory->deactivateParcStatus($params);
            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    public function insertStatusParc($row)
    {
        try {
            $this->connection->beginTransaction();
            $params = array(
                "NRPARCNEGOCIO"         => $row["NRPARCNEGOCIO"],
                "NRPARCRESP"            => $row["NRPARCRESP"],
                "CDOPERRESP"            => $row["CDOPERRESPONSAVEL"],
                "STATUSPARC"            => $row["CDTIPOPARCEIRO"],
                "NRORG"                 => $row["NRORG"],
                "CRM_NRORGTRAB"         => $row["CRM_NRORGTRAB"],
                "IDATIVO"               => $row["IDATIVO"],
                "CDOPERINCLUSAO"        => $row["CDOPERINCLUSAO"],
                "IDSTATUS"              => $row["IDSTATUS"]
            );

            $this->LeadFactory->insertStatusParc($params);
            $this->connection->commit();
        } catch (\Throwable $th) {
            $this->connection->rollBack();
            throw $th;
        }
    }

    private function checkReceiveModeInfo($row)
    {
        try {
            $params = array(
                "NRORG" => $this->Environment->getNrOrg(),
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
            );

            return $this->LeadFactory->checkReceiveModeInfo($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateModoRecebInfo($row)
    {
        try {
            $params = array(
                "NRORG" => $this->Environment->getNrOrg(),
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "NRMODORECEBINFO" => $row['NRMODORECEBINFO'],
            );

            return $this->LeadFactory->updateModoRecebInfo($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveComunicaparc($row)
    {
        $this->saveEmailComunicaparc($row);
        $this->saveTelefoneComunicaparc($row);
    }

    private function saveEmailComunicaparc($row)
    {
        try {
            if (!empty($row['DSEMAILCAN'])) {
                $findParcComunication = $this->getComunicaparc($row['DSEMAILCAN'], ['05'], $row['NRPARCNEGOCIO'], $row['NRORG']);
                if (empty($findParcComunication)) {
                    $params = array(
                        "CDCOMUNICAPARC" => $row['DSEMAILCAN'],
                        "IDATIVO"        => $row['IDATIVO'],
                        "NRCOMUNICAPARC" => $this->newCode->getCodeByTableName("COMUNICAPARC", $row['NRORG'], 1, 10, false, true),
                        "NRPARCNEGOCIO"  => $row['NRPARCNEGOCIO'],
                        "CDFORMACOMU"    => '05',
                        "NRORG"          => $row['NRORG'],
                        "NRORGINCLUSAO"  => $row['NRORG'],
                        "CDOPERINCLUSAO" => $row['CDOPERADOR'],
                    );
                    $this->LeadFactory->insertComunicaparc($params);
                }
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function saveTelefoneComunicaparc($row)
    {
        if (!empty($row['DSTELEFONECAN'])) {
            // Verifique e insira ou atualize o telefone do comunicado aqui
            if (!empty($row['DSTELEFONECAN'])) {
                $findParcPhone = $this->getComunicaparc($row['DSTELEFONECAN'], ['01', '02', '03', '04'], $row['NRPARCNEGOCIO'], $row['NRORG']);
                if (empty($findParcPhone)) {
                    $findParcPrincipalPhone = $this->getPhonePrinc($row['NRPARCNEGOCIO'], '01', $row['NRORG']);
                    if (empty($findParcPrincipalPhone)) {
                        $params = array(
                            "CDCOMUNICAPARC" => $row['DSTELEFONECAN'],
                            "IDATIVO"        => $row['IDATIVO'],
                            "NRCOMUNICAPARC" => $this->newCode->getCodeByTableName("COMUNICAPARC", $row['NRORG'], 1, 10, false, true),
                            "NRPARCNEGOCIO"  => $row['NRPARCNEGOCIO'],
                            "CDFORMACOMU"    => '01',
                            "NRORG"          => $row['NRORG'],
                            "NRORGINCLUSAO"  => $row['NRORG'],
                            "CDOPERINCLUSAO" => $row['CDOPERADOR'],
                        );
                        $this->LeadFactory->insertComunicaparc($params);
                    } else {
                        $this->LeadFactory->updateMainPhone($row['DSTELEFONECAN'], $row['NRPARCNEGOCIO'], $row['NRORG']);
                    }
                }
            }
        }
    }

    private function getComunicaparc($value, $type, $nrparcnegocio, $nrorg)
    {
        try {
            $params = array(
                "CDCOMUNICAPARC"        => $value,
                "CDFORMACOMU"           => join(',', $type),
                "NRPARCNEGOCIO"         => $nrparcnegocio,
                "NRORG"                 => $nrorg
            );

            return $this->LeadFactory->getComunicaparc($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    private function getPhonePrinc($nrparcnegocio, $cdformacomu, $nrorg): array
    {
        try {
            $params = array(
                "NRPARCNEGOCIO" => $nrparcnegocio,
                "CDFORMACOMU"   => $cdformacomu,
                "NRORG"         => $nrorg
            );

            return $this->LeadFactory->getPhonePrinc($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveDtnascifundparc($row): void
    {
        try {
            $params = array(
                "NRPARCNEGOCIO"   => $row['NRPARCNEGOCIO'],
                "DTNASCIFUNDPARC" => !empty($row['DTNASCIFUNDPARC']) ? $row['DTNASCIFUNDPARC'] : "",
                "NRORG"           => $row['NRORG'],
            );
            $this->LeadFactory->saveDtnascifundparc($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveAddressParc($row)
    {
        try {

            $nrParcNegocio = $row['NRPARCNEGOCIO'];
            $nrOrg = $row['NRORG'];
            $cdOperInclusao = empty($row['CDOPERINCLUSAO']) ? $row['CDOPERADOR'] : $this->Environment->getCdOperador();
            $cdPais = $row['CDPAIS'] ?? '';
            $sgEstado = $row['SGESTADO'] ?? '';
            $cdMunicipio = $row['CDMUNICIPIO'] ?? '';
            $adressType = $row['CDTIPOENDERECO'] ?? 'PRINCIPAL';
            $cdBairro = $row['CDBAIRRO'] ?? '';
            $nrCepEndereco = $row['NRCEPENDERECO'] ?? '';
            $idativo = $row['IDATIVO'] ?? 'S';
            $dsEndereco = $row['DSENDERECO'] ?? '';
            $nrImovelEndereco = $row['NRIMOVELENDERECO'] ?? '';
            $dsCompleEndereco = $row['DSCOMPLEENDERECO'] ?? '';

            $nrEnderecoParc = $this->LeadFactory->getAddressParc($nrParcNegocio, $nrOrg, $adressType);

            $params = [
                "NRORG" => $nrOrg,
                "NRPARCNEGOCIO" => $nrParcNegocio,
                "IDATIVO" => $idativo,
                "CDOPERINCLUSAO" => $cdOperInclusao,
                "CDPAIS" => $cdPais,
                "SGESTADO" => $sgEstado,
                "CDMUNICIPIO" => $cdMunicipio,
                "CDTIPOENDERECO" => $adressType,
                "NRENDERECOPARC" => $nrEnderecoParc,
                "CDBAIRRO" => $cdBairro,
                "NRCEPENDERECO" => $nrCepEndereco,
                "DSENDERECO" => $dsEndereco,
                "NRIMOVELENDERECO" => $nrImovelEndereco,
                "DSCOMPLEENDERECO" => $dsCompleEndereco,
                "NRORGINCLUSAO" => $nrOrg,
            ];

            if (empty($nrEnderecoParc)) {
                $nrEnderecoParc = $this->newCode->getCodeByTableName("ENDERECOPARC", $row["NRORG"], 1, 10, false, false);
                $params['NRENDERECOPARC'] = $nrEnderecoParc;
                $this->LeadFactory->insertAddressParc($params);
            } else {
                $this->LeadFactory->updateAddressParc($params);
            }
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function updateResponsavel($row)
    {
        try {

            $nrparcoper = NULL;
            $cdoper = NULL;

            if (!empty($row['NRPARCPROPRI'])) {
                $operador = $this->getOperatorInformation($row['NRORG'], $row['NRPARCPROPRI']);
                if (!empty($operador)) {
                    $nrparcoper = $operador['NRPARCNEGOCIO'];
                    $cdoper = $operador['CDOPERADOR'];
                    if (empty($nrparcoper)) {
                        $nrparcoper = $operador[0]['NRPARCNEGOCIO'];
                        $cdoper = $operador[0]['CDOPERADOR'];
                    }
                }
            }

            $params = array(
                "NRORG" => $row['NRORG'],
                "CRM_NRORGTRAB" => $row['NRORG'],
                "NRPARCNEGOCIO" => $row['NRPARCNEGOCIO'],
                "NRPARCRESP" => $nrparcoper,
                "CDOPERRESP" => $cdoper,
                "NRPARCPROPRI" => $row['NRPARCPROPRI'],
            );

            $this->LeadFactory->updateResponsavel($params);
        } catch (\Exception $e) {
            throw $e;
        }
    }

    public function saveLead(array $leadData): void
    {
        try {
            $this->connection->beginTransaction();

            $cleanedLeadData = $this->prepareLeadData($leadData);
            $this->LeadFactory->saveLead($cleanedLeadData);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    private function prepareLeadData(array $leadData): array
    {
        return [
            "NRCANDIDATO" => $leadData['NRCANDIDATO'],
            "DESCTITULOCAN" => $leadData['DESCTITULOCAN'] ?? null,
            "IDTPIJURCAN" => $this->normalizeIDTPIJURCAN($leadData['IDTPIJURCAN']),
            "NRINSJURCAN" => $leadData['NRINSJURCAN'],
            "NMCANDIDATO" => $leadData['NMCANDIDATO'],
            "NMFANTCAN" => $leadData['NMFANTCAN'],
            "DSEMAILCAN" => $leadData['DSEMAILCAN'] ?? null,
            "DSTELEFONECAN" => $leadData['DSTELEFONECAN'] ?? null,
            "IDSTATUSCAN" => $leadData['IDSTATUSCAN'] ?? null,
            "CDSEGMER" => $leadData['CDSEGMER'][0] ?? null,
            "NRFUNCCAN" => $leadData['NRFUNCCAN'] ?? null,
            "CDMODODIVULG" => $leadData['CDMODODIVULG'] ?? null,
            "CDPAIS" => $leadData['CDPAIS'] ?? null,
            "SGESTADO" => $leadData['SGESTADO'] ?? null,
            "CDMUNICIPIO" => $leadData['CDMUNICIPIO'] ?? null,
            "CDBAIRRO" => $leadData['CDBAIRRO'] ?? null,
            "NMBAIRROCAN" => $leadData['NMBAIRROCAN'] ?? null,
            "NRPARCPROPRI" => $leadData['NRPARCPROPRI'] ?? null,
            "NRPARCNEGOCIO" => $leadData['NRPARCNEGOCIO'] ?? null,
            "CDFILIAL" => $leadData['CDFILIAL'] ?? null,
            "NRCONTATO" => $leadData['NRCONTATO'] ?? null,
            "NRORG" => $leadData['NRORG'] ?? null,
            "IDATIVO" => $leadData['IDATIVO'] ?? null,
            "NRORGINCLUSAO" => $leadData['NRORG'] ?? null,
            "CDOPERINCLUSAO" => $leadData['CDOPERADOR'] ?? null,
            "NRORGULTATU" => $leadData['NRORG'] ?? null,
            "CDOPERULTATU" => $leadData['CDOPERADOR'] ?? null,
            "IDPARCFUNDIDO" => $leadData['IDPARCFUNDIDO'] ?? null,
            "NRSEQCONTATO" => $leadData['NRSEQCONTATO'] ?? null,
            "DSOBSERVACAOLEAD" => $leadData['DSOBSERVACAOLEAD'] ?? null,
            "NRIMOVELENDERECO" => $leadData['NRIMOVELENDERECO'] ?? null,
            "NRSEQPERFILRESPONSAVEL" => $leadData['NRSEQPERFILRESPONSAVEL'] ?? null,
            "PORTCANDIDATO" => $leadData['PORTCANDIDATO'] ?? null,
            "QNTDUSUARIOS" => $leadData['QNTDUSUARIOS'] ?? null,
            "QNTDUNIDADES" => $leadData['QNTDUNIDADES'] ?? null,
            "QNTPONTOSACESSO" => $leadData['QNTPONTOSACESSO'] ?? null,
            "FISCAL" => $leadData['FISCAL'] ?? null,
            "CDMODATEND" => $leadData['CDMODATEND'] ?? null,
            "NRREFEICOESDIA" => $leadData['NRREFEICOESDIA'] ?? null,
            "NRSISATUAL" => $leadData['NRSISATUAL'] ?? null,
        ];
    }

    public function qualifyLead(array $leadData): void
    {
        try {
            $this->connection->beginTransaction();

            $cleanedLeadData = $this->prepareDataForQualify($leadData);
            $this->LeadFactory->qualifyLead($cleanedLeadData);

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollBack();
            throw $e;
        }
    }

    private function prepareDataForQualify(array $leadData): array
    {
        return [
            "IDSTATUSCAN" => $leadData['IDSTATUSCAN'],
            "NRORG" => $leadData['NRORG'],
            "CRM_NRORGTRAB" => $leadData['NRORG'],
            "CDOPERULTATU" => $leadData['CDOPERULTATU'],
            "NRPARCNEGOCIO" => $leadData['NRPARCNEGOCIO'],
        ];
    }
}
